@@ -6,10 +6,13 @@ from .compiler import (
     compileTeal,
 )
 
+from .optimizer import OptimizeOptions
+
 __all__ = [
     "MAX_TEAL_VERSION",
     "MIN_TEAL_VERSION",
     "DEFAULT_TEAL_VERSION",
     "CompileOptions",
     "compileTeal",
+    "OptimizeOptions",
 ]
